@@ -30,24 +30,25 @@
 
 from test.base import BaseTest
 
-from pygasus import Field, Model
+from pygasus import Model
 from pygasus.exceptions import *
 
 class Book(Model):
 
     """A simple book model."""
 
-    title = Field(str)
-    author = Field(str)
-    year = Field(int)
+    title: str
+    author: str
+    year: int
 
 class TestModels(BaseTest):
 
     """Test the model API."""
 
+    models = (Book, )
+
     def setUp(self):
         super().setUp()
-        self.db.bind((Book, ))
 
     def test_create(self):
         """Create several instances."""
